
unit Settings;

interface

uses
  SysUtils;

procedure LoadSettings(
  out APos: string;
  out AFenFile: TFileName;
  out APositionIndex: integer;
  out ADepth: integer;
  out AFromFile: boolean
);
procedure SaveSettings(
  const APos: string;
  const AFenFile: TFileName;
  const APositionIndex: integer;
  const ADepth: integer;
  const AFromFile: boolean
);
  
implementation

uses
  IniFiles;

const
  CSection = 'main';
  CDefaultPosition = 'b7/PP6/8/8/7K/6B1/6N1/4R1bk w - -';
  CDefaultDepth = 3;
  CDefaultFile = 'fen/155075mi2.fen';
{
  El Arte del Mate en Dos
  Eduardo Sadier
  https://sites.google.com/site/edusadier/home
}
  CDefaultFromFile = FALSE;

var
  LIniFileName: TFileName;
  
procedure LoadSettings(
  out APos: string;
  out AFenFile: TFileName;
  out APositionIndex: integer;
  out ADepth: integer;
  out AFromFile: boolean
);
begin
  with TIniFile.Create(LIniFileName) do
  try
    APos := ReadString(CSection, 'currentposition', CDefaultPosition);
    AFenFile := ReadString(CSection, 'file', CDefaultFile);
    APositionIndex := ReadInteger(CSection, 'positionindex', 1);
    ADepth := ReadInteger(CSection, 'searchdepth', CDefaultDepth);
    AFromFile := ReadInteger(CSection, 'fromfile', Ord(CDefaultFromFile)) <> 0;
  finally
    Free;
  end;
end;

procedure SaveSettings(
  const APos: string;
  const AFenFile: TFileName;
  const APositionIndex: integer;
  const ADepth: integer;
  const AFromFile: boolean
);
begin
  with TIniFile.Create(LIniFileName) do
  try
    WriteString(CSection, 'currentposition', APos);
    WriteString(CSection, 'file', AFenFile);
    WriteInteger(CSection, 'positionindex', APositionIndex);
    WriteInteger(CSection, 'searchdepth', ADepth);
    WriteInteger(CSection, 'fromfile', Ord(AFromFile));
    UpdateFile;
  finally
    Free;
  end;
end;

begin
  LIniFileName := ChangeFileExt(ParamStr(0), '.ini');
end.

